<?php
namespace Elementor;

/**
 * @package     WordPress
 * @subpackage  Responsive Tab for Elementor
 * @author      support@themegum.com
 * @since       1.0.0
*/

if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}



use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Icons_Manager;
use Elementor\Repeater;
use Elementor\Core\Schemes;

/**
 * Elementor responsive tab widget.
 *
 *
 * @since 1.0.0
 */
class Widget_Temegum_Restab extends Widget_Base {


  public function __construct( $data = [], $args = null ) {
    parent::__construct( $data, $args );

    $is_type_instance = $this->is_type_instance();

    if ( ! $is_type_instance && null === $args ) {
      throw new \Exception( '`$args` argument is required when initializing a full widget instance.' );
    }

    add_action( 'elementor/element/before_section_start', [ $this, 'enqueue_script' ] );

    if ( $is_type_instance ) {
      $this->_register_skins();

      $widget_name = $this->get_name();

      /**
       * Widget skin init.
       *
       * Fires when Elementor widget is being initialized.
       *
       * The dynamic portion of the hook name, `$widget_name`, refers to the widget name.
       *
       * @since 1.0.0
       *
       * @param Widget_Base $this The current widget.
       */
      do_action( "elementor/widget/{$widget_name}/skins_init", $this );
    }
  }


  /**
   * Get widget name.
   *
   * Retrieve button widget name.
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'el-restab';
  }

  /**
   * Get widget title.
   *
   * Retrieve button widget title.
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return esc_html__( 'Responsive Tab', 'restab-for-elementor' );
  }

  /**
   * Get widget icon.
   *
   * Retrieve button widget icon.
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-tabs';
  }

  /**
   * Get widget categories.
   *
   * Retrieve the list of categories the button widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * @since 2.0.0
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'temegum' ];
  }

  /**
   * Register widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.0.0
   * @access protected
   */
  protected function _register_controls() {

  $this->start_controls_section(
      'section_content',
      [
        'label' => esc_html__( 'Content', 'restab-for-elementor' ),
      ]
    );

    $repeater = new Repeater();

    $repeater->add_control(
      'tab_title',
      [
        'label' => esc_html__( 'Heading', 'restab-for-elementor' ),
        'type' => Controls_Manager::TEXT,
        'default' => esc_html__( 'Title Text', 'restab-for-elementor' ),
        'label_block' => true,
      ]
    );

    $repeater->add_control(
      'tab_content',
      [
        'label' => esc_html__( 'Content', 'restab-for-elementor' ),
        'type' => Controls_Manager::WYSIWYG,
        'default' => esc_html__( 'Timeline Content', 'restab-for-elementor' ),
        'label_block' => true,
      ]
    );


    $repeater->add_control(
      'content_align',
      [
        'label' => esc_html__( 'Content Alignment', 'restab-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
              'left' => [
                'title' => esc_html__( 'Left', 'restab-for-elementor' ),
                'icon' => 'eicon-text-align-left',
              ],
              'center' => [
                'title' => esc_html__( 'Center', 'restab-for-elementor' ),
                'icon' => 'eicon-text-align-center',
              ],
              'right' => [
                'title' => esc_html__( 'Right', 'restab-for-elementor' ),
                'icon' => 'eicon-text-align-right',
              ]



        ],
        'default' => 'center',
      ]
    );


    $this->add_control(
      'tabs',
      [
        'label' => esc_html__( 'Tabs', 'restab-for-elementor' ),
        'type' => Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        'default' => [
          [
            'tab_title' => esc_html__( 'Tab #1', 'restab-for-elementor' ),
            'tab_content' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'restab-for-elementor' ),
          ],
          [
            'tab_title' => esc_html__( 'Tab #2', 'restab-for-elementor' ),
            'tab_content' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'restab-for-elementor' ),
          ],
          [
            'tab_title' => esc_html__( 'Tab #3', 'restab-for-elementor' ),
            'tab_content' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'restab-for-elementor' ),
          ],
        ],
        'title_field' => '{{{ tab_title }}}',
      ]
    );



    $this->add_responsive_control(
      'tab_mode',
      [
        'label' => esc_html__( 'Mode', 'restab-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'options' => [
            'tab'   => esc_html__('Tab','restab-for-elementor') ,
            'accordeon' => esc_html__('Accordion','restab-for-elementor') ,
        ],
        'default' => 'tab',
        'separator' => 'before',
      ]
    );


    $this->add_control(
      'accordion_icon_title',
      [
        'label' => esc_html__( 'Accordion Icon', 'restab-for-elementor' ),
        'type' => Controls_Manager::HEADING,
        'separator' => 'before',
      ]
    );


    $this->add_control(
      'accordion_icon',
      [
        'label' => esc_html__( 'Close', 'restab-for-elementor' ),
        'type' => Controls_Manager::ICONS,
        'fa4compatibility' => 'icon',
        'exclude_inline_options'=>['svg'],
        'recommended' => [
          'fa-solid' => [
            'fa-plus',
            'chevron-down',
            'angle-down',
            'angle-double-down',
            'caret-down',
            'caret-square-down',
          ],
          'fa-regular' => [
            'caret-square-down',
          ],
        ],
        'skin' => 'inline',
        'label_block' => false,
      ]
    );

    $this->add_control(
      'accordion_active_icon',
      [
        'label' => esc_html__( 'Open', 'restab-for-elementor' ),
        'type' => Controls_Manager::ICONS,
        'fa4compatibility' => 'icon_active',
        'exclude_inline_options'=>['svg'],
        'recommended' => [
          'fa-solid' => [
            'fa-minus',
            'chevron-up',
            'angle-up',
            'angle-double-up',
            'caret-up',
            'caret-square-up',
          ],
          'fa-regular' => [
            'caret-square-up',
          ],
        ],
        'skin' => 'inline',
        'label_block' => false,
        'condition' => [
          'accordion_icon[value]!' => '',
        ],
      ]
    );

  $this->end_controls_section();


/*
 * style params
 */

    $this->start_controls_section(
      'section_style_box',
      [
        'label' => esc_html__( 'Tab Mode', 'restab-for-elementor' ),
        'tab'   => Controls_Manager::TAB_STYLE,
      ]
    );    


    $this->add_control(
      'style_tab_title',
      [
        'label' => esc_html__( 'Title', 'restab-for-elementor' ),
        'type' => Controls_Manager::HEADING,
      ]
    );


    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'typography_heading',
        'selector' => '{{WRAPPER}} .nav-tabs li > a,{{WRAPPER}} .panel-group .panel .panel-heading a',
         'separator' => 'before',
      ]
    );


    $this->add_control(
      'title_align',
      [
        'label' => esc_html__( 'Text Alignment', 'restab-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
              'left' => [
                'title' => esc_html__( 'Left', 'restab-for-elementor' ),
                'icon' => 'eicon-text-align-left',
              ],
              'center' => [
                'title' => esc_html__( 'Center', 'restab-for-elementor' ),
                'icon' => 'eicon-text-align-center',
              ],
              'right' => [
                'title' => esc_html__( 'Right', 'restab-for-elementor' ),
                'icon' => 'eicon-text-align-right',
              ]
        ],
        'selectors' => [
          '{{WRAPPER}} .nav-tabs > li' => 'text-align: {{VALUE}};',
        ],

      ]
    );


    $this->add_control(
      'tab_align',
      [
        'label' => esc_html__( 'Alignment', 'restab-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
              'left' => [
                'title' => esc_html__( 'Left', 'restab-for-elementor' ),
                'icon' => 'eicon-h-align-left',
              ],
              'center' => [
                'title' => esc_html__( 'Center', 'restab-for-elementor' ),
                'icon' => 'eicon-h-align-center',
              ],
              'right' => [
                'title' => esc_html__( 'Right', 'restab-for-elementor' ),
                'icon' => 'eicon-h-align-right',
              ],
              'justify' => [
                'title' => esc_html__( 'Justify', 'restab-for-elementor' ),
                'icon' => 'eicon-h-align-stretch',
              ]

        ],
      ]
    );


    $this->add_responsive_control(
      'tab_gap',
      [
        'label' => esc_html__( 'Spacing', 'restab-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .nav-tabs > li:not(last-child)' => 'margin-right: {{SIZE}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'tab_indent',
      [
        'label' => esc_html__( 'Tab indent', 'restab-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .nav-tabs' => 'padding: 0 {{SIZE}}{{UNIT}};',
        ],
      ]
    );



    $this->add_responsive_control(
      'tab_offsett',
      [
        'label' => esc_html__( 'Content Offset', 'restab-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .nav-tabs' => 'margin-bottom: -{{SIZE}}{{UNIT}};',
        ],
      ]
    );



    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'panel_border',
        'selector' => '{{WRAPPER}} .nav-tabs li > a',
      ]
    );

    $this->add_control(
      'panel_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'restab-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .nav-tabs li > a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_control(
      'panel_padding',
      [
        'label' => esc_html__( 'Padding', 'restab-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .nav-tabs li > a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->start_controls_tabs( 'heading_colors_style' );
    $this->start_controls_tab(
      'heading_color_style',
      [
        'label' => esc_html__( 'Normal', 'restab-for-elementor' ),
      ]
    );

    $this->add_control(
      'heading_color',
      [
        'label' => esc_html__( 'Color', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .nav-tabs li > a' => 'color: {{VALUE}};',
        ]
      ]
    );


    $this->add_control(
      'heading_bgcolor',
      [
        'label' => esc_html__( 'Background', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .nav-tabs li > a' => 'background-color: {{VALUE}};',
        ]
      ]
    );

    $this->end_controls_tab();
    $this->start_controls_tab(
      'heading_hover_color_style',
      [
        'label' => esc_html__( 'Hover/Tab Active', 'restab-for-elementor' ),
      ]
    );


    $this->add_control(
      'heading_hover_color',
      [
        'label' => esc_html__( 'Color', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .nav-tabs li > a:hover,{{WRAPPER}} .nav-tabs li > a:focus,{{WRAPPER}} .nav-tabs li.active > a,{{WRAPPER}} .nav-tabs li.in-active > a' => 'color: {{VALUE}}!important;',
        ]
      ]
    );


    $this->add_control(
      'heading_hover_bordercolor',
      [
        'label' => esc_html__( 'Border', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .nav-tabs li.active > a,{{WRAPPER}} .nav-tabs li.in-active > a,{{WRAPPER}} .nav-tabs li > a:hover' => 'border-color: {{VALUE}}!important;',
        ],
        'condition' => [
          'panel_border_border!' => '',
        ],

      ]
    );



    $this->add_control(
      'heading_hover_bgcolor',
      [
        'label' => esc_html__( 'Background', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .nav-tabs li.active > a,{{WRAPPER}} .nav-tabs li.in-active > a,{{WRAPPER}} .nav-tabs li > a:hover' => 'background-color: {{VALUE}}!important;',
        ]
      ]
    );


    $this->end_controls_tab();
    $this->end_controls_tabs();
    $this->end_controls_section();

/* accordion style */

    $this->start_controls_section(
      'section_style_accordion',
      [
        'label' => esc_html__( 'Accordion Mode', 'restab-for-elementor' ),
        'tab'   => Controls_Manager::TAB_STYLE,
      ]
    );    

    $this->add_control(
      'style_accordion_title',
      [
        'label' => esc_html__( 'Icon', 'restab-for-elementor' ),
        'type' => Controls_Manager::HEADING,
      ]
    );

    $this->add_control(
      'accordion_align',
      [
        'label' => esc_html__( 'Icon Position', 'restab-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
              'left' => [
                'title' => esc_html__( 'Left', 'restab-for-elementor' ),
                'icon' => 'eicon-h-align-left',
              ],
              'right' => [
                'title' => esc_html__( 'Right', 'restab-for-elementor' ),
                'icon' => 'eicon-h-align-right',
              ]

        ],
      ]
    );


    $this->add_control(
      'accordion_icon_size',
      [
        'label' => esc_html__( 'Size', 'restab-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .panel-title .accordion-icon' => 'font-size: {{SIZE}}{{UNIT}};',
        ],
        'description' =>esc_html__( 'Change to accordion mode if want see the result/style', 'restab-for-elementor' ),
      ]
    );


    $this->add_control(
      'accordion_icon_offset',
      [
        'label' => esc_html__( 'X Offset', 'restab-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => -100,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .responsive_tab:not(.icon-left) .panel-title .accordion-icons' => 'margin-left: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .responsive_tab.icon-left .panel-title .accordion-icons' => 'margin-right: {{SIZE}}{{UNIT}};',
        ],
      ]
    );


    $this->add_control(
      'accordion_icon_color',
      [
        'label' => esc_html__( 'Accordion Close', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .panel-title:not(.openedup) .accordion-icon' => 'color: {{VALUE}};',
        ]
      ]
    );

    $this->add_control(
      'accordion_icon_hovercolor',
      [
        'label' => esc_html__( 'Accordion Open', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .panel-heading.openedup .accordion-icon' => 'color: {{VALUE}};',
        ]
      ]
    );

    $this->add_control(
      'style_title_accordion_title',
      [
        'label' => esc_html__( 'Title', 'restab-for-elementor' ),
        'type' => Controls_Manager::HEADING,
        'separator' => 'before',
      ]
    );


    $this->add_control(
      'accordion_title_align',
      [
        'label' => esc_html__( 'Text Alignment', 'restab-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
              'left' => [
                'title' => esc_html__( 'Left', 'restab-for-elementor' ),
                'icon' => 'eicon-text-align-left',
              ],
              'center' => [
                'title' => esc_html__( 'Center', 'restab-for-elementor' ),
                'icon' => 'eicon-text-align-center',
              ],
              'right' => [
                'title' => esc_html__( 'Right', 'restab-for-elementor' ),
                'icon' => 'eicon-text-align-right',
              ]
        ],
        'selectors' => [
          '{{WRAPPER}} .panel-group  .panel-heading' => 'text-align: {{VALUE}};',
        ],

      ]
    );

    $this->add_responsive_control(
      'accordion_gap',
      [
        'label' => esc_html__( 'Spacing', 'restab-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .panel-group .panel + .panel' => 'margin-top: {{SIZE}}{{UNIT}};',
        ],
      ]
    );


    $this->add_control(
      'accordion_offsett',
      [
        'label' => esc_html__( 'Content Offset', 'restab-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => -200,
            'max' => 200,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .panel-group .panel-collapse' => 'margin-top: {{SIZE}}{{UNIT}};',
        ],
      ]
    );



    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'accordion_border',
        'selector' => '{{WRAPPER}} .panel-group .panel .panel-heading',
      ]
    );

    $this->add_control(
      'accordion_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'restab-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .panel-group .panel .panel-heading' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );




    $this->add_control(
      'accordion_title_padding',
      [
        'label' => esc_html__( 'Padding', 'restab-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .panel-group .panel .panel-title a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $this->start_controls_tabs( 'accordion_colors_style' );
    $this->start_controls_tab(
      'accordion_color_style',
      [
        'label' => esc_html__( 'Normal', 'restab-for-elementor' ),
      ]
    );

    $this->add_control(
      'accordion_color',
      [
        'label' => esc_html__( 'Color', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .panel-group .panel .panel-heading a' => 'color: {{VALUE}};',
        ]
      ]
    );


    $this->add_control(
      'accordion_bgcolor',
      [
        'label' => esc_html__( 'Background', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .panel-group .panel.panel-default .panel-heading' => 'background-color: {{VALUE}};',
        ]
      ]
    );

    $this->end_controls_tab();
    $this->start_controls_tab(
      'accordion_hover_color_style',
      [
        'label' => esc_html__( 'Hover/Tab Active', 'restab-for-elementor' ),
      ]
    );


    $this->add_control(
      'accordion_hover_color',
      [
        'label' => esc_html__( 'Color', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .panel-group .panel .panel-heading.openedup a,{{WRAPPER}} .panel-group .panel:hover .panel-heading a' => 'color: {{VALUE}}!important;',
        ]
      ]
    );


    $this->add_control(
      'accordion_hover_bordercolor',
      [
        'label' => esc_html__( 'Border', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .panel-group .panel .panel-heading.openedup,{{WRAPPER}} .panel-group .panel:hover .panel-heading' => 'border-color: {{VALUE}}!important;',
        ],
        'condition' => [
          'accordion_border!' => '',
        ],

      ]
    );



    $this->add_control(
      'accordion_hover_bgcolor',
      [
        'label' => esc_html__( 'Background', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .panel-group .panel .panel-heading.openedup,{{WRAPPER}} .panel-group .panel:hover .panel-heading' => 'background-color: {{VALUE}}!important;',
        ]
      ]
    );


    $this->end_controls_tab();
    $this->end_controls_tabs();


    $this->end_controls_section();

    $this->start_controls_section(
      'content_title',
      [
        'label' => esc_html__( 'Content', 'restab-for-elementor' ),
        'tab'   => Controls_Manager::TAB_STYLE,
      ]
    );


    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'typography_content',
        'selector' => '{{WRAPPER}} .tab-content .tab-pane,{{WRAPPER}} .tab-content .tab-pane p,{{WRAPPER}} .panel-group .panel-body,.panel-group .panel-body p',
      ]
    );


    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'content_border',
        'selector' => '{{WRAPPER}} .tab-content,{{WRAPPER}} .panel .panel-body',
        'separator' => 'before',
      ]
    );


    $this->add_control(
      'content_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'restab-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .tab-content,{{WRAPPER}} .panel .panel-body' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'content_padding',
      [
        'label' => esc_html__( 'Padding', 'restab-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .tab-content,{{WRAPPER}} .panel-group .panel-body' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_control(
      'content_color',
      [
        'label' => esc_html__( 'Color', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tab-content .tab-pane,{{WRAPPER}} .tab-content .tab-pane p' => 'color: {{VALUE}};',
          '{{WRAPPER}} .panel-group .panel-body,{{WRAPPER}} .panel-group .panel-body p' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'content_bgcolor',
      [
        'label' => esc_html__( 'Background', 'restab-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tab-content,{{WRAPPER}} .panel-group .panel-body' => 'background-color: {{VALUE}};',
        ],
      ]
    );


    $this->add_group_control(
     Group_Control_Box_Shadow::get_type(),
      [
        'name' => 'content__shadow',
        'selector' => '{{WRAPPER}} .tab-content,{{WRAPPER}} .panel-group .panel-body',
      ]
    );

    $this->end_controls_section();

  }

  /**
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.0.0
   * @access protected
   */
  protected function render() {

    $settings = $this->get_settings_for_display();

    extract( $settings );

    $el_id = $_element_id;
    $css_class=array('responsive_tab','icon-'.$accordion_align);

    if(''!=$_css_classes){
        array_push($css_class, $_css_classes);
    }

    $cn_list = $cn_preview = $cn_accordeon=array();
    $tab_css_class = array('nav-tabs','responsive');
    $icon_tab = '';

    

    if($tab_align!=''){
      array_push( $tab_css_class, 'panel-'.$tab_align);
    }

    $has_icon = ! empty( $accordion_icon['value'] );

    if( $has_icon ){
      $active_icon = !empty( $accordion_active_icon['value'] ) ? $accordion_active_icon['value'] : 'fa fa-minus';

      $icon_tab = '<span class="accordion-icons"><span class="accordion-icon accordion-open"><i class="'.esc_attr($accordion_icon['value']).'"></i></span>';
      $icon_tab .= '<span class="accordion-icon accordion-collapse"><i class="'.esc_attr($active_icon).'"></i></span></span>';
    }



    $tabid=  substr( $this->get_id_int(), 0, 3 );
    $itemnumber=0;



    foreach ($tabs as $tab) {


        $class_att =($itemnumber==0)?"in-active":"";
        $cn_item='<li '.($class_att !=''? 'class="'.$class_att.'"' : '').'><a href="#tabid_'.$tabid.'_'.$itemnumber.'">'.($has_icon ? $icon_tab : '').'<span>'.$tab['tab_title'].'</span></a></li>';
        $cn_preview_item='<div id="tabid_'.$tabid.'_'.$itemnumber.'" class="tab-pane align-'.$tab['content_align'].(($itemnumber==0)?" in active":"").'">'.$tab['tab_content'].'</div>';

        array_push($cn_list, $cn_item);
        array_push($cn_preview, $cn_preview_item);

        $itemnumber++;
    }


    $compile="<div ";
    if(''!=$el_id){
        $compile.="id=\"$el_id\" ";
    }

    $compile.='class="'.@implode(" ",$css_class).'">';


    $compile.='<ul id="tabid_'.$tabid.'" class="'.implode(' ', $tab_css_class).'">'.implode("\n",$cn_list).'
      </ul>'."\n".'<div class="tab-content responsive">
                '.implode("\n",$cn_preview).'</div>'."\n";

    $compile.='</div>';

        if($tab_mode !='tab'){
          array_push($cn_accordeon,"'lg'");
        }

        if($tab_mode_tablet !='tab'){
          array_push($cn_accordeon,"'sm'");
        }

        if($tab_mode_mobile !='tab'){
          array_push($cn_accordeon,"'xs'");
        }


$compile.='<script type="text/javascript">
jQuery(document).ready(function($){
  $( \'#tabid_'.$tabid.' a\' ).click( function ( e ) {
        e.preventDefault();
        $( this ).tab( \'show\' );
  } );';

if(count($cn_accordeon)){
  $compile.='fakewaffle.responsiveTabs( $( \'#tabid_'.$tabid.'\' ),['.@implode(',', $cn_accordeon).'] );';
}
$compile.='});
</script>';

    print $compile;
  }

    /**
   * Render  output in the editor.
   * still blank for prevent overwriting
   *
   * @since 1.0.0
   * @access protected
   */

  protected function content_template() {

  }


  public function enqueue_script( ) {

    wp_enqueue_script( 'bootstrap' , RESTAB_ELEMENTOR_URL.'js/bootstrap.js', array( 'jquery' ), '3.0', false );
    wp_enqueue_script( 'bootstrap-responsivetab', RESTAB_ELEMENTOR_URL . 'js/responsive-tabs.js', array(), '1.0', false );
    wp_enqueue_style( 'bootstrap-tabs',RESTAB_ELEMENTOR_URL."css/bootstrap_vertical_tab.css",array());

  }

}

// Register widget
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widget_Temegum_Restab() );
?>
